lcvtoolbox.integrations.cvat.api.compile\_task.CvatApiShape
===========================================================

.. currentmodule:: lcvtoolbox.integrations.cvat.api.compile_task

.. autoclass:: CvatApiShape
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CvatApiShape.__init__
      ~CvatApiShape.construct
      ~CvatApiShape.copy
      ~CvatApiShape.dict
      ~CvatApiShape.from_orm
      ~CvatApiShape.json
      ~CvatApiShape.model_construct
      ~CvatApiShape.model_copy
      ~CvatApiShape.model_dump
      ~CvatApiShape.model_dump_json
      ~CvatApiShape.model_json_schema
      ~CvatApiShape.model_parametrized_name
      ~CvatApiShape.model_post_init
      ~CvatApiShape.model_rebuild
      ~CvatApiShape.model_validate
      ~CvatApiShape.model_validate_json
      ~CvatApiShape.model_validate_strings
      ~CvatApiShape.parse_file
      ~CvatApiShape.parse_obj
      ~CvatApiShape.parse_raw
      ~CvatApiShape.schema
      ~CvatApiShape.schema_json
      ~CvatApiShape.update_forward_refs
      ~CvatApiShape.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CvatApiShape.model_computed_fields
      ~CvatApiShape.model_config
      ~CvatApiShape.model_extra
      ~CvatApiShape.model_fields
      ~CvatApiShape.model_fields_set
      ~CvatApiShape.id
      ~CvatApiShape.type
      ~CvatApiShape.occluded
      ~CvatApiShape.z_order
      ~CvatApiShape.points
      ~CvatApiShape.rotation
      ~CvatApiShape.outside
      ~CvatApiShape.attributes
      ~CvatApiShape.frame
      ~CvatApiShape.label_id
      ~CvatApiShape.source
   
   